Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to '3rdparty/Sabre/CalDAV/Backend/Abstract.php')
-rw-r--r--3rdparty/Sabre/CalDAV/Backend/Abstract.php15
1 files changed, 6 insertions, 9 deletions
diff --git a/3rdparty/Sabre/CalDAV/Backend/Abstract.php b/3rdparty/Sabre/CalDAV/Backend/Abstract.php
index 7ac282f44a0..b694eef49e4 100644
--- a/3rdparty/Sabre/CalDAV/Backend/Abstract.php
+++ b/3rdparty/Sabre/CalDAV/Backend/Abstract.php
@@ -36,20 +36,17 @@ abstract class Sabre_CalDAV_Backend_Abstract {
* If the creation was a success, an id must be returned that can be used to reference
* this calendar in other methods, such as updateCalendar.
*
- * This function must return a server-wide unique id that can be used
- * later to reference the calendar.
- *
* @param string $principalUri
* @param string $calendarUri
* @param array $properties
- * @return string|int
+ * @return void
*/
abstract function createCalendar($principalUri,$calendarUri,array $properties);
/**
- * Updates properties on this node,
+ * Updates properties for a calendar.
*
* The properties array uses the propertyName in clark-notation as key,
* and the array value for the property value. In the case a property
* should be deleted, the property value will be null.
*
@@ -79,10 +76,10 @@ abstract class Sabre_CalDAV_Backend_Abstract {
* (424 Failed Dependency) because the request needs to be atomic.
*
* @param string $calendarId
- * @param array $properties
+ * @param array $mutations
* @return bool|array
*/
- public function updateCalendar($calendarId, array $properties) {
+ public function updateCalendar($calendarId, array $mutations) {
return false;
@@ -97,7 +94,7 @@ abstract class Sabre_CalDAV_Backend_Abstract {
abstract function deleteCalendar($calendarId);
/**
- * Returns all calendar objects within a calendar object.
+ * Returns all calendar objects within a calendar.
*
* Every item contains an array with the following keys:
* * id - unique identifier which will be used for subsequent updates
@@ -36,20 +36,17 @@ abstract class Sabre_CalDAV_Backend_Abstract {
*
- * The properties array uses the propertyName in clark-notation as key,
+ * The mutations array uses the propertyName in clark-notation as key,
* and the array value for the property value. In the case a property
* should be deleted, the property value will be null.